summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/dialogs/classifierlistpage.h
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/dialogs/classifierlistpage.h')
-rw-r--r--umbrello/umbrello/dialogs/classifierlistpage.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/umbrello/umbrello/dialogs/classifierlistpage.h b/umbrello/umbrello/dialogs/classifierlistpage.h
index 7f0e298f..2675fd35 100644
--- a/umbrello/umbrello/dialogs/classifierlistpage.h
+++ b/umbrello/umbrello/dialogs/classifierlistpage.h
@@ -43,12 +43,12 @@ public:
/**
* Sets up the ClassifierListPage
*
* @param tqparent The tqparent to the ClassAttPage.
* @param classifier The Concept to display the properties of.
* @param doc The UMLDoc document
* @param type The type of listItem this handles
*/
- ClassifierListPage(TQWidget* tqparent, UMLClassifier* classifier, UMLDoc* doc, Uml::Object_Type type);
+ ClassifierListPage(TQWidget* parent, UMLClassifier* classifier, UMLDoc* doc, Uml::Object_Type type);
/**
* Standard deconstructor.
@@ -43,12 +43,12 @@ public:
* Sets up the ClassifierListPage
*
- * @param tqparent The tqparent to the ClassAttPage.
+ * @param parent The parent to the ClassAttPage.
* @param classifier The Concept to display the properties of.
* @param doc The UMLDoc document